==> 134003-kencfs-1.3.1.tar.gz: kencfs-1.3.1/kencfs_cs_CZ.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>KEncFs - (c) 2010 by Felice Murolo - Salerno - Italia</source>
        <translation>KEncFs - (c) 2010 by Felice Murolo - Salerno - Italia - Český překlad Milos.Kozina@postino.net</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="27"/>
        <source>Encrypted FileSystem</source>
        <translation>Zašifrovaný souborový systém</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="88"/>
        <source>&amp;Remove</source>
        <translation>O&amp;debrat</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="100"/>
        <source>&amp;Mount</source>
        <translation>&amp;Připojit</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="107"/>
        <source>&amp;Umount</source>
        <translation>&amp;Odpojit</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="75"/>
        <source>&amp;Add</source>
        <translation>Přid&amp;at</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="114"/>
        <source>&amp;Browse</source>
        <translation>P&amp;rocházet</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="134"/>
        <source>&amp;Hide</source>
        <translation>Skrý&amp;t</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="141"/>
        <location filename="mainwindow.ui" line="210"/>
        <source>&amp;Exit</source>
        <translation>U&amp;končit</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="164"/>
        <source>&amp;File</source>
        <translation>&amp;Soubor</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="186"/>
        <source>&amp;Hide / Show</source>
        <translation>Skrý&amp;t / Zobrazit</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="189"/>
        <source>Hide / Show</source>
        <translation>Skrýt / Zobrazit</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="194"/>
        <source>&amp;Config</source>
        <translation>&amp;Nastavení</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="197"/>
        <source>Config</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="202"/>
        <source>&amp;About</source>
        <translation>&amp;O programu</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="205"/>
        <source>About</source>
        <translation>O programu</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="213"/>
        <source>Exit</source>
        <translation>Ukončit</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="83"/>
        <source>Mount Point</source>
        <translation>Přípojný bod</translation>
    </message>
    <message>
        <source>Crypted Directory</source>
        <translation type="obsolete">Directory Criptata</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="83"/>
        <source>FileSystem ID</source>
        <translation>ID souborového systému</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="83"/>
        <source>Status</source>
        <translation>Stav</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="83"/>
        <source>Encrypted Directory</source>
        <translation>Zašifrovaný adresář</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="98"/>
        <source>Add</source>
        <translation>Přidat</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="99"/>
        <source>Remove</source>
        <translation>Odebrat</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="100"/>
        <source>Mount</source>
        <translation>Připojit</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="101"/>
        <source>Umount</source>
        <translation>Odpojit</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="102"/>
        <source>Browse</source>
        <translation>Procházet</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="225"/>
        <source>Do really you want to remove FileSystem &apos;</source>
        <translation>Opravdu chcete odebrat souborový systém &apos;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="226"/>
        <source>Remove FileSystem</source>
        <translation>Odebrat souborový systém</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="266"/>
        <source>Mounted</source>
        <translation>Připojeno</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="381"/>
        <source>Donations</source>
        <translation>Dary</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="381"/>
        <source>Please, consider to make a &lt;a href=&apos;http://kde-apps.org/content/donate.php?content=134003&apos;&gt;Donation&lt;/a&gt; for my work.
If you like this application, please donate something.
All money raised will be donated to charity for meritorious initiatives.

</source>
        <translation>Prosím zvažte &lt;a href=&apos;http://kde-apps.org/content/donate.php?content=134003&apos;&gt;příspěvěk&lt;/a&gt; jako ocenění mé práce.
Pokud se Vám aplikace líbí, přispějte prosím.
Všechny vybrané peníze budou věnovány na charitu nebo podobné záslužné účely.

</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="main.cpp" line="33"/>
        <source>I couldn&apos;t detect any system tray on this system.</source>
        <translation>Nepodařilo se mi nalézt systémovou oblast (system tray) na tomto počítači.</translation>
    </message>
</context>
<context>
    <name>configDialog</name>
    <message>
        <location filename="configdialog.ui" line="14"/>
        <source>KEncFS - Confguration</source>
        <translation>KEncFS - Nastavení</translation>
    </message>
    <message>
        <location filename="configdialog.ui" line="32"/>
        <source>&amp;Start in TrayBar</source>
        <translation>&amp;Spustit v systémové oblasti (SysTray)</translation>
    </message>
    <message>
        <location filename="configdialog.ui" line="62"/>
        <source>&amp;Use KDE Wallet</source>
        <translation>&amp;Používat správce úschovny KDE</translation>
    </message>
    <message>
        <location filename="configdialog.ui" line="22"/>
        <source>&amp;Browse after mount</source>
        <translation>&amp;Procházet po připojení</translation>
    </message>
</context>
<context>
    <name>fsDialog</name>
    <message>
        <location filename="fsdialog.ui" line="14"/>
        <source>KEncFs - Add FileSystem</source>
        <translation>KEncFs - Přidat souborový systém</translation>
    </message>
    <message>
        <location filename="fsdialog.ui" line="22"/>
        <source>FileSystem ID</source>
        <translation>ID souborového systému</translation>
    </message>
    <message>
        <location filename="fsdialog.ui" line="36"/>
        <source>Mountpoint</source>
        <translation>Přípojný bod</translation>
    </message>
    <message>
        <location filename="fsdialog.ui" line="50"/>
        <location filename="fsdialog.ui" line="71"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="fsdialog.ui" line="57"/>
        <source>Encrypted Directory</source>
        <translation>Zašifrovaný adresář</translation>
    </message>
    <message>
        <location filename="fsDialog.cpp" line="67"/>
        <source>Select encrypted existing directory or create new</source>
        <translation>Vyberte existující zašifrovaný adresář nebo vytvořte nový</translation>
    </message>
    <message>
        <location filename="fsDialog.cpp" line="75"/>
        <source>Select mountpoint existing directory or create new</source>
        <translation>Vyberte adresář pro přípojný bod nebo vytvořte nový</translation>
    </message>
    <message>
        <location filename="fsDialog.cpp" line="92"/>
        <location filename="fsDialog.cpp" line="198"/>
        <source>Mounted</source>
        <translation>Připojeno</translation>
    </message>
    <message>
        <location filename="fsDialog.cpp" line="46"/>
        <location filename="fsDialog.cpp" line="49"/>
        <location filename="fsDialog.cpp" line="52"/>
        <location filename="fsDialog.cpp" line="125"/>
        <location filename="fsDialog.cpp" line="126"/>
        <location filename="fsDialog.cpp" line="164"/>
        <source>Fatal Error</source>
        <translation>Chyba připojování</translation>
    </message>
    <message>
        <location filename="fsDialog.cpp" line="46"/>
        <source>Warning! &apos;encfs&apos; is not installed.

Please, install it!

</source>
        <translation>Pozor! &apos;encfs&apos; není nainstalován.

Nainstalujte ho, prosím!

</translation>
    </message>
    <message>
        <location filename="fsDialog.cpp" line="49"/>
        <source>Warning! &apos;fusermount&apos; is not installed.

Please, install it!

</source>
        <translation>Pozor! &apos;fusermount&apos; není nainstalován.

Nainstalujte ho, prosím!

</translation>
    </message>
    <message>
        <location filename="fsDialog.cpp" line="52"/>
        <source>Warning! &apos;dolphin&apos; is not installed.

Please, install it!

</source>
        <translation>Pozor! &apos;dolphin&apos; není nainstalován.

Nainstalujte ho, prosím!

</translation>
    </message>
    <message>
        <location filename="fsDialog.cpp" line="125"/>
        <source>Warning! MountPoint directory doesn&apos;t exists

</source>
        <translation>Pozor! Adresář pro přípojný bod neexistuje

</translation>
    </message>
    <message>
        <location filename="fsDialog.cpp" line="126"/>
        <source>Warning! Encrypted directory doesn&apos;t exists

</source>
        <translation>Pozor! Zašifrovaný adresář neexistuje

</translation>
    </message>
    <message>
        <location filename="fsDialog.cpp" line="145"/>
        <source>Password for Encrypted FileSystem:</source>
        <translation>Heslo pro zašifrovaný souborový systém:</translation>
    </message>
    <message>
        <location filename="fsDialog.cpp" line="162"/>
        <source>Mount Error!

</source>
        <translation></translation>
    </message>
    <message>
        <location filename="fsDialog.cpp" line="163"/>
        <source>Error returned from Encfs:
</source>
        <oldsource>Encfs returns:
</oldsource>
        <translation>Chyba vrácená z encfs:</translation>
    </message>
    <message>
        <source>Mount error!

</source>
        <translation type="obsolete">Chyba připojování!</translation>
    </message>
    <message>
        <source>Warning! Crypted directory doesn&apos;t exists

</source>
        <translation type="obsolete">Attenzione! La directory criptata non esiste

</translation>
    </message>
    <message>
        <location filename="fsDialog.cpp" line="145"/>
        <source>Password Request</source>
        <translation>Zadejte prosím heslo</translation>
    </message>
</context>
</TS>

==> 134003-kencfs-1.4.0.tar.gz: kencfs-1.4.0/kencfs_cs_CZ.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs_CZ">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>KEncFs - (c) 2010 by Felice Murolo - Salerno - Italia</source>
        <translation>KEncFs - (c) 2010 by Felice Murolo - Salerno - Italia - Český překlad Milos.Kozina@postino.net</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="27"/>
        <source>Encrypted FileSystem</source>
        <translation>Zašifrovaný souborový systém</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="88"/>
        <source>&amp;Remove</source>
        <translation>O&amp;debrat</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="100"/>
        <source>&amp;Mount</source>
        <translation>&amp;Připojit</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="107"/>
        <source>&amp;Umount</source>
        <translation>&amp;Odpojit</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="75"/>
        <source>&amp;Add</source>
        <translation>Přid&amp;at</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="114"/>
        <source>&amp;Browse</source>
        <translation>P&amp;rocházet</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="134"/>
        <source>&amp;Hide</source>
        <translation>Skrý&amp;t</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="141"/>
        <location filename="mainwindow.ui" line="210"/>
        <source>&amp;Exit</source>
        <translation>U&amp;končit</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="164"/>
        <source>&amp;File</source>
        <translation>&amp;Soubor</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="186"/>
        <source>&amp;Hide / Show</source>
        <translation>Skrý&amp;t / Zobrazit</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="189"/>
        <source>Hide / Show</source>
        <translation>Skrýt / Zobrazit</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="194"/>
        <source>&amp;Config</source>
        <translation>&amp;Nastavení</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="197"/>
        <source>Config</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="202"/>
        <source>&amp;About</source>
        <translation>&amp;O programu</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="205"/>
        <source>About</source>
        <translation>O programu</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="213"/>
        <source>Exit</source>
        <translation>Ukončit</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="84"/>
        <source>Mount Point</source>
        <translation>Přípojný bod</translation>
    </message>
    <message>
        <source>Crypted Directory</source>
        <translation type="obsolete">Directory Criptata</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="84"/>
        <source>FileSystem ID</source>
        <translation>ID souborového systému</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="84"/>
        <source>Status</source>
        <translation>Stav</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="84"/>
        <source>Encrypted Directory</source>
        <translation>Zašifrovaný adresář</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="99"/>
        <source>Add</source>
        <translation>Přidat</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="100"/>
        <source>Remove</source>
        <translation>Odebrat</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="101"/>
        <source>Mount</source>
        <translation>Připojit</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="102"/>
        <source>Umount</source>
        <translation>Odpojit</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="103"/>
        <source>Browse</source>
        <translation>Procházet</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="251"/>
        <source>Do really you want to remove FileSystem &apos;</source>
        <translation>Opravdu chcete odebrat souborový systém &apos;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="252"/>
        <source>Remove FileSystem</source>
        <translation>Odebrat souborový systém</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="292"/>
        <source>Mounted</source>
        <translation>Připojeno</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="407"/>
        <source>Donations</source>
        <translation>Dary</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="407"/>
        <source>Please, consider to make a &lt;a href=&apos;http://kde-apps.org/content/donate.php?content=134003&apos;&gt;Donation&lt;/a&gt; for my work.
If you like this application, please donate something.
All money raised will be donated to charity for meritorious initiatives.

</source>
        <translation>Prosím zvažte &lt;a href=&apos;http://kde-apps.org/content/donate.php?content=134003&apos;&gt;příspěvěk&lt;/a&gt; jako ocenění mé práce.
Pokud se Vám aplikace líbí, přispějte prosím.
Všechny vybrané peníze budou věnovány na charitu nebo podobné záslužné účely.

</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="main.cpp" line="33"/>
        <source>I couldn&apos;t detect any system tray on this system.</source>
        <translation>Nepodařilo se mi nalézt systémovou oblast (system tray) na tomto počítači.</translation>
    </message>
</context>
<context>
    <name>configDialog</name>
    <message>
        <location filename="configdialog.ui" line="14"/>
        <source>KEncFS - Confguration</source>
        <translation>KEncFS - Nastavení</translation>
    </message>
    <message>
        <location filename="configdialog.ui" line="32"/>
        <source>&amp;Start in TrayBar</source>
        <translation>&amp;Spustit v systémové oblasti (SysTray)</translation>
    </message>
    <message>
        <location filename="configdialog.ui" line="62"/>
        <source>&amp;Use KDE Wallet</source>
        <translation>&amp;Používat správce úschovny KDE</translation>
    </message>
    <message>
        <location filename="configdialog.ui" line="72"/>
        <source>&amp;Try AutoMount on start (KDE Wallet must be enabled)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="configdialog.ui" line="22"/>
        <source>&amp;Browse after mount (not for AutoMount function) </source>
        <oldsource>&amp;Browse after mount</oldsource>
        <translation type="unfinished">&amp;Procházet po připojení</translation>
    </message>
</context>
<context>
    <name>fsDialog</name>
    <message>
        <location filename="fsdialog.ui" line="14"/>
        <source>KEncFs - Add FileSystem</source>
        <translation>KEncFs - Přidat souborový systém</translation>
    </message>
    <message>
        <location filename="fsdialog.ui" line="22"/>
        <source>FileSystem ID</source>
        <translation>ID souborového systému</translation>
    </message>
    <message>
        <location filename="fsdialog.ui" line="36"/>
        <source>Mountpoint</source>
        <translation>Přípojný bod</translation>
    </message>
    <message>
        <location filename="fsdialog.ui" line="50"/>
        <location filename="fsdialog.ui" line="71"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="fsdialog.ui" line="57"/>
        <source>Encrypted Directory</source>
        <translation>Zašifrovaný adresář</translation>
    </message>
    <message>
        <location filename="fsDialog.cpp" line="67"/>
        <source>Select encrypted existing directory or create new</source>
        <translation>Vyberte existující zašifrovaný adresář nebo vytvořte nový</translation>
    </message>
    <message>
        <location filename="fsDialog.cpp" line="75"/>
        <source>Select mountpoint existing directory or create new</source>
        <translation>Vyberte adresář pro přípojný bod nebo vytvořte nový</translation>
    </message>
    <message>
        <location filename="fsDialog.cpp" line="92"/>
        <location filename="fsDialog.cpp" line="205"/>
        <source>Mounted</source>
        <translation>Připojeno</translation>
    </message>
    <message>
        <location filename="fsDialog.cpp" line="46"/>
        <location filename="fsDialog.cpp" line="49"/>
        <location filename="fsDialog.cpp" line="52"/>
        <location filename="fsDialog.cpp" line="125"/>
        <location filename="fsDialog.cpp" line="126"/>
        <location filename="fsDialog.cpp" line="174"/>
        <source>Fatal Error</source>
        <translation>Chyba připojování</translation>
    </message>
    <message>
        <location filename="fsDialog.cpp" line="46"/>
        <source>Warning! &apos;encfs&apos; is not installed.

Please, install it!

</source>
        <translation>Pozor! &apos;encfs&apos; není nainstalován.

Nainstalujte ho, prosím!

</translation>
    </message>
    <message>
        <location filename="fsDialog.cpp" line="49"/>
        <source>Warning! &apos;fusermount&apos; is not installed.

Please, install it!

</source>
        <translation>Pozor! &apos;fusermount&apos; není nainstalován.

Nainstalujte ho, prosím!

</translation>
    </message>
    <message>
        <location filename="fsDialog.cpp" line="52"/>
        <source>Warning! &apos;dolphin&apos; is not installed.

Please, install it!

</source>
        <translation>Pozor! &apos;dolphin&apos; není nainstalován.

Nainstalujte ho, prosím!

</translation>
    </message>
    <message>
        <location filename="fsDialog.cpp" line="125"/>
        <source>Warning! MountPoint directory doesn&apos;t exists

</source>
        <translation>Pozor! Adresář pro přípojný bod neexistuje

</translation>
    </message>
    <message>
        <location filename="fsDialog.cpp" line="126"/>
        <source>Warning! Encrypted directory doesn&apos;t exists

</source>
        <translation>Pozor! Zašifrovaný adresář neexistuje

</translation>
    </message>
    <message>
        <location filename="fsDialog.cpp" line="145"/>
        <source>Password for Encrypted FileSystem:</source>
        <translation>Heslo pro zašifrovaný souborový systém:</translation>
    </message>
    <message>
        <location filename="fsDialog.cpp" line="172"/>
        <source>Mount Error!

</source>
        <translation></translation>
    </message>
    <message>
        <location filename="fsDialog.cpp" line="173"/>
        <source>Error returned from Encfs:
</source>
        <oldsource>Encfs returns:
</oldsource>
        <translation>Chyba vrácená z encfs:</translation>
    </message>
    <message>
        <source>Mount error!

</source>
        <translation type="obsolete">Chyba připojování!</translation>
    </message>
    <message>
        <source>Warning! Crypted directory doesn&apos;t exists

</source>
        <translation type="obsolete">Attenzione! La directory criptata non esiste

</translation>
    </message>
    <message>
        <location filename="fsDialog.cpp" line="145"/>
        <source>Password Request</source>
        <translation>Zadejte prosím heslo</translation>
    </message>
</context>
</TS>
